@@ -3,7 +3,9 @@ SIGN_IN   = 'SIGN_IN'
 SIGN_UP   = 'SIGN_UP'
 CHG_PSW   = 'CHG_PSW'
 FORGOT_PSW = 'FORGOT_PSW'
-TEST_REPORT = 'TEST_REPORT'
+TEST_REPORT_EMAIL = 'SET_REPORT_EMAIL'
+GET_REPORT = 'GET_REPORT'
+GET_REPORT_EMAIL = 'GET_REPORT_EMAIL'
 
 POWER_BUTTON_PIN     =3
 EN_5VCC_PIN          =5 
@@ -153,7 +155,7 @@ ADDRESS =["finch","Toronto","Canada"]
 #@SIGNATURE = "client=laipac&signature=laipacws"
 #USER      = "userid=feng.gao@laipac.com&password=123456"
 SERIAL_NO = "654321"
-CASSETTE_DETECTION_MODE_AUTO   = 'AUTO MODE'
+CASSETTE_DETECTION_MODE_AUTO   = 'AUTO MODE  '
 CASSETTE_DETECTION_MODE_MANUAL = 'MANUAL MODE'
 
 MAIN_PARA_CASSETTE_TYPE_CHIP = 'chip'
